- 9a0ca23 Add description in toml (Dinesh, 2025-07-14)
- db1a396 fix source link in Readme (Dinesh, 2025-07-14)
- 4bee5fb Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- f60ba74 Update README.md (Dinesh Ravi, 2025-07-14)
- b3b4d68 Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- ccdadff Update README.md (Dinesh Ravi, 2025-07-14)
- e5c249e update license link in readme (Dinesh Ravi, 2025-07-14)
- 4f73381 Update pyproject.toml (Dinesh Ravi, 2025-07-14)
- 0107c2c Update README.md (Dinesh Ravi, 2025-07-14)
- 4b1d89c update to 0.1.1 (Dinesh Ravi, 2025-07-14)
- c180117 Update README.md (Dinesh Ravi, 2025-07-14)
- e905a5a updated readme (Dinesh, 2025-07-14)
- 5a9d3fa all license screenshot (Dinesh, 2025-07-14)
- d2a2d99 improve change log (Dinesh, 2025-07-14)
- 5568ec7 add screenshots (Dinesh, 2025-07-14)
- 6227d95 update changelog (Dinesh, 2025-07-14)
- f943e59 first commit (Dinesh, 2025-07-14)